### R code from vignette source 'DAKS.Rnw'

###################################################
### code chunk number 1: preliminaries
###################################################
library("DAKS")
library("relations")
library("sets")
options(prompt="R> ", continue="R+", width=70)


###################################################
### code chunk number 2: integer
###################################################
1 == 1L


###################################################
### code chunk number 3: pisa1
###################################################
head(pisa)
pat <- pattern(pisa)
pat
sum(pat$response.patterns)


###################################################
### code chunk number 4: pisa2
###################################################
apply(pisa, 2, table)


###################################################
### code chunk number 5: iita
###################################################
mini <- iita(pisa, v = 1)
corr <- iita(pisa, v = 2)
orig <- iita(pisa, v = 3)
summary(mini)
summary(corr)
summary(orig)


###################################################
### code chunk number 6: selection-set
###################################################
sel_set <- ind_gen(ob_counter(pisa))
sel_set


###################################################
### code chunk number 7: set-operations1
###################################################
set_symdiff(orig$implications, mini$implications)


###################################################
### code chunk number 8: set-operations2
###################################################
set_is_proper_subset(orig$implications, mini$implications)


###################################################
### code chunk number 9: z-test
###################################################
z_test(pisa, sel_set[[10]], sel_set[[9]], alternative = "less", v = 1)


###################################################
### code chunk number 10: simulated-data
###################################################
ex_data <- simu(9, 1500, 0.1, 0.1, delta = 0.15)


###################################################
### code chunk number 11: simulated-relation
###################################################
ex_data$implications


###################################################
### code chunk number 12: corr-iita1
###################################################
ex_corr <- iita(ex_data$dataset, v = 2)
ex_corr


###################################################
### code chunk number 13: corr-iita2
###################################################
ex_corr$implications == ex_data$implications


###################################################
### code chunk number 14: pop-iita
###################################################
pop <- pop_iita(ex_data$implications, 0.1, 0.1, 9, dataset = ex_data$dataset, v = 2)
attributes(pop)


###################################################
### code chunk number 15: diff1
###################################################
round(ex_corr$diff / 1500^2, 4)


###################################################
### code chunk number 16: diff2
###################################################
round(pop$pop.diff, 4)


###################################################
### code chunk number 17: pop-relation
###################################################
mp <- which.min(pop$pop.diff)
pop$selection.set[[mp]] 


###################################################
### code chunk number 18: est-var
###################################################
var_sample <- variance(ex_data$dataset, ex_data$implications, v = 2)
var_sample
sqrt(var_sample)


###################################################
### code chunk number 19: pop-var
###################################################
pop_variance <- pop_variance(pop$pop.matrix, pop$selection.set[[mp]], pop$error.pop[mp], v = 2)
pop_variance
sqrt(pop_variance)


